custom_adaptive_scaffold library

Classes

AdaptiveBody
Exposes whether the active layout is currently collapsed (single-pane).
AdaptiveLayout
Layout an app that adapts to different screens using predefined slots.
AdaptiveScaffold
Implements the basic visual layout structure for Material Design 3 that adapts to a variety of screens.
AdaptiveScaffoldController
Controls pane intent for primary/secondary style layouts in AdaptiveScaffold.
AdaptiveScaffoldScope
Provides AdaptiveScaffoldController to descendants via InheritedNotifier.
Breakpoint
A class to define the conditions that distinguish between types of screens.
Breakpoints
A group of standard breakpoints built according to the material specifications for screen width size.
DualPanel
A responsive layout that displays a primary body and an optional secondary body side-by-side on wider screens.
DualPanelNavigationConfig
Configuration for navigation elements displayed alongside a DualPanel shell.
ExpandedRailDestination
Expanded layout used to render a single NavigationRail destination.
Material 3 Navigation Bar component.
A Material 3 NavigationBar destination.
An inherited widget that defines visual properties for NavigationBars and NavigationDestinations in this widget's subtree.
Defines default property values for descendant NavigationBar widgets.
A navigation destination widget that can be used with NavigationBar, NavigationRail, or AdaptiveScaffold.
Animated selection indicator pill used by both NavigationBar and NavigationRail destinations.
A Material Design widget that is meant to be displayed at the left or right of an app to navigate between a small number of views, typically between three and five.
A NavigationRail destination that can display a widget label.
An inherited widget that defines visual properties for NavigationRails and NavigationRailDestinations in this widget's subtree.
Defines default property values for descendant NavigationRail widgets.
RailDestination
Builds a single NavigationRail destination across collapsed and extended rail layouts.
SlotLayout
A Widget that takes a mapping of SlotLayoutConfigs to Breakpoints and adds the appropriate Widget based on the current screen size.
SlotLayoutConfig
Defines how SlotLayout should display under a certain Breakpoint.
SplitView
An inherited widget that exposes whether the current layout is in a split-view (side-by-side) configuration.
SplitViewDetector
A widget that detects the current split-view state and notifies via onChanged.
WrappedRailDestination
Stateless wrapper that applies the ink-well, indicator, semantics, and tap handler around a rail destination's content widget.

Enums

Controls how a badge is displayed on a NavigationDestination icon.
Identifies which navigation surface owns this indicator.
PanelFocus
Indicates which pane should be focused when a layout is collapsed.

Constants

kMaterialCompactMargin → const double
Margin value of the compact breakpoint according to the material design 3 spec.
kMaterialCompactSpacing → const double
Spacing value of the compact breakpoint according to the material 3 design spec.
kMaterialMediumAndUpMargin → const double
Margin value of the medium breakpoint according to the material design 3 spec.
kMaterialMediumAndUpSpacing → const double
Spacing value of the medium and up breakpoint according to the material 3 design spec.
kMaterialPadding → const double
Padding value of the compact breakpoint according to the material design 3 spec.