dual_panel library

Classes

DualPanel
A responsive layout that displays a primary body and an optional secondary body side-by-side on wider screens.
DualPanelNavigationConfig
Configuration for navigation elements displayed alongside a DualPanel shell.
SplitView
An inherited widget that exposes whether the current layout is in a split-view (side-by-side) configuration.
SplitViewDetector
A widget that detects the current split-view state and notifies via onChanged.