markNeedsPaint abstract method
void
markNeedsPaint()
Notifies the controller that one of its ink features needs to repaint.
Implementation
void markNeedsPaint();
Notifies the controller that one of its ink features needs to repaint.
void markNeedsPaint();