vsync property
TickerProvider
get
vsync
The ticker provider used by the controller.
Ink features that are added to this controller with addInkFeature should use this vsync to drive their animations.
Implementation
TickerProvider get vsync;