dateHelpText abstract method
The help text used on an empty InputDatePickerFormField to indicate to the user the date format being asked for.
Implementation
String dateHelpText(MaterialLocalizations localizations);
The help text used on an empty InputDatePickerFormField to indicate to the user the date format being asked for.
String dateHelpText(MaterialLocalizations localizations);