dateOnly abstract method
T
dateOnly(
- T date
Returns a DateTime with the date of the original, but time set to midnight.
Implementation
T dateOnly(T date);
Returns a DateTime with the date of the original, but time set to midnight.
T dateOnly(T date);