formatShortMonthDay abstract method
Formats the month and day of the given date.
Examples:
- US English: Feb 21
- Russian: 21 февр.
Implementation
String formatShortMonthDay(T date, MaterialLocalizations localizations);
Formats the month and day of the given date.
Examples:
String formatShortMonthDay(T date, MaterialLocalizations localizations);