shape property
The shape of the card's Material.
Defines the card's Material.shape.
If null, the ambient CardTheme.shape from ThemeData.cardTheme is used. If that is also null, the shape defaults to a RoundedRectangleBorder. The default corner radius is 12.0 when ThemeData.useMaterial3 is true, and 4.0 otherwise. For Material 3 outlined cards, the default shape also includes a border side (see OutlinedBorder.side).
Implementation
final ShapeBorder? shape;