iconTheme property
Overrides the default for ChipAttributes.iconTheme, the theme used for all icons in the chip.
This property applies to ActionChip, Chip, ChoiceChip, FilterChip, InputChip, RawChip.
Implementation
final IconThemeData? iconTheme;
Overrides the default for ChipAttributes.iconTheme, the theme used for all icons in the chip.
This property applies to ActionChip, Chip, ChoiceChip, FilterChip, InputChip, RawChip.
final IconThemeData? iconTheme;