onPrimaryFixed property
Color
get
onPrimaryFixed
A color that is used for text and icons that exist on top of elements having primaryFixed color.
Implementation
Color get onPrimaryFixed => _onPrimaryFixed ?? onPrimary;