onSecondaryFixed property
Color
get
onSecondaryFixed
A color that is used for text and icons that exist on top of elements having secondaryFixed color.
Implementation
Color get onSecondaryFixed => _onSecondaryFixed ?? onSecondary;