shadow property
Color
get
shadow
A color use to paint the drop shadows of elevated components.
Implementation
Color get shadow => _shadow ?? const Color(0xff000000);
A color use to paint the drop shadows of elevated components.
Color get shadow => _shadow ?? const Color(0xff000000);