surfaceDim property
Color
get
surfaceDim
A color that's always darkest in the dark or light theme.
Implementation
Color get surfaceDim => _surfaceDim ?? surface;
A color that's always darkest in the dark or light theme.
Color get surfaceDim => _surfaceDim ?? surface;