tertiaryFixed property
Color
get
tertiaryFixed
A substitute for tertiaryContainer that's the same color for dark and light themes.
Implementation
Color get tertiaryFixed => _tertiaryFixed ?? tertiary;
A substitute for tertiaryContainer that's the same color for dark and light themes.
Color get tertiaryFixed => _tertiaryFixed ?? tertiary;