amber constant
MaterialColor
const amber
The amber primary color and swatch.



Icon(
Icons.widgets,
color: Colors.amber[400],
)
See also:
- amberAccent, the corresponding accent colors.
- yellow and orange, similar colors.
- Theme.of, which allows you to select colors from the current theme rather than hard-coding colors in your build methods.
Implementation
// TODO(framework): Add unit tests to this code snippet.
// https://github.com/flutter/flutter/issues/188530
///
/// ```dart
/// Icon(
/// Icons.widgets,
/// color: Colors.amber[400],
/// )
/// ```
///
/// </callout-box>
///
/// See also:
///
/// * [amberAccent], the corresponding accent colors.
/// * [yellow] and [orange], similar colors.
/// * [Theme.of], which allows you to select colors from the current theme
/// rather than hard-coding colors in your build methods.
static const MaterialColor amber = MaterialColor(_amberPrimaryValue, <int, Color>{
50: Color(0xFFFFF8E1),
100: Color(0xFFFFECB3),
200: Color(0xFFFFE082),
300: Color(0xFFFFD54F),
400: Color(0xFFFFCA28),
500: Color(_amberPrimaryValue),
600: Color(0xFFFFB300),
700: Color(0xFFFFA000),
800: Color(0xFFFF8F00),
900: Color(0xFFFF6F00),
});