blue constant

MaterialColor const blue

The blue primary color and swatch.

Icon(
  Icons.widgets,
  color: Colors.blue[400],
)

See also:

  • blueAccent, the corresponding accent colors.
  • indigo, lightBlue, and blueGrey, similar colors.
  • Theme.of, which allows you to select colors from the current theme rather than hard-coding colors in your build methods.

Implementation

// TODO(framework): Add unit tests to this code snippet.
// https://github.com/flutter/flutter/issues/188530
///
/// ```dart
/// Icon(
///   Icons.widgets,
///   color: Colors.blue[400],
/// )
/// ```
///
/// </callout-box>
///
/// See also:
///
///  * [blueAccent], the corresponding accent colors.
///  * [indigo], [lightBlue], and [blueGrey], similar colors.
///  * [Theme.of], which allows you to select colors from the current theme
///    rather than hard-coding colors in your build methods.
static const MaterialColor blue = MaterialColor(_bluePrimaryValue, <int, Color>{
  50: Color(0xFFE3F2FD),
  100: Color(0xFFBBDEFB),
  200: Color(0xFF90CAF9),
  300: Color(0xFF64B5F6),
  400: Color(0xFF42A5F5),
  500: Color(_bluePrimaryValue),
  600: Color(0xFF1E88E5),
  700: Color(0xFF1976D2),
  800: Color(0xFF1565C0),
  900: Color(0xFF0D47A1),
});