blueGrey constant

MaterialColor const blueGrey

The blue-grey primary color and swatch.

This swatch has no corresponding accent swatch.

Icon(
  Icons.widgets,
  color: Colors.blueGrey[400],
)

See also:

  • grey, cyan, and blue, similar colors.
  • Theme.of, which allows you to select colors from the current theme rather than hard-coding colors in your build methods.

Implementation

// TODO(framework): Add unit tests to this code snippet.
// https://github.com/flutter/flutter/issues/188530
///
/// ```dart
/// Icon(
///   Icons.widgets,
///   color: Colors.blueGrey[400],
/// )
/// ```
///
/// </callout-box>
///
/// See also:
///
///  * [grey], [cyan], and [blue], similar colors.
///  * [Theme.of], which allows you to select colors from the current theme
///    rather than hard-coding colors in your build methods.
static const MaterialColor blueGrey = MaterialColor(_blueGreyPrimaryValue, <int, Color>{
  50: Color(0xFFECEFF1),
  100: Color(0xFFCFD8DC),
  200: Color(0xFFB0BEC5),
  300: Color(0xFF90A4AE),
  400: Color(0xFF78909C),
  500: Color(_blueGreyPrimaryValue),
  600: Color(0xFF546E7A),
  700: Color(0xFF455A64),
  800: Color(0xFF37474F),
  900: Color(0xFF263238),
});