brown constant

MaterialColor const brown

The brown primary color and swatch.

This swatch has no corresponding accent color and swatch.

Icon(
  Icons.widgets,
  color: Colors.brown[400],
)

See also:

  • orange and blueGrey, vaguely similar colors.
  • Theme.of, which allows you to select colors from the current theme rather than hard-coding colors in your build methods.

Implementation

// TODO(framework): Add unit tests to this code snippet.
// https://github.com/flutter/flutter/issues/188530
///
/// ```dart
/// Icon(
///   Icons.widgets,
///   color: Colors.brown[400],
/// )
/// ```
///
/// </callout-box>
///
/// See also:
///
///  * [orange] and [blueGrey], vaguely similar colors.
///  * [Theme.of], which allows you to select colors from the current theme
///    rather than hard-coding colors in your build methods.
static const MaterialColor brown = MaterialColor(_brownPrimaryValue, <int, Color>{
  50: Color(0xFFEFEBE9),
  100: Color(0xFFD7CCC8),
  200: Color(0xFFBCAAA4),
  300: Color(0xFFA1887F),
  400: Color(0xFF8D6E63),
  500: Color(_brownPrimaryValue),
  600: Color(0xFF6D4C41),
  700: Color(0xFF5D4037),
  800: Color(0xFF4E342E),
  900: Color(0xFF3E2723),
});