deepPurple constant

MaterialColor const deepPurple

The deep purple primary color and swatch.

Icon(
  Icons.widgets,
  color: Colors.deepPurple[400],
)

See also:

  • deepPurpleAccent, the corresponding accent colors.
  • purple and indigo, similar colors.
  • Theme.of, which allows you to select colors from the current theme rather than hard-coding colors in your build methods.

Implementation

// TODO(framework): Add unit tests to this code snippet.
// https://github.com/flutter/flutter/issues/188530
///
/// ```dart
/// Icon(
///   Icons.widgets,
///   color: Colors.deepPurple[400],
/// )
/// ```
///
/// </callout-box>
///
/// See also:
///
///  * [deepPurpleAccent], the corresponding accent colors.
///  * [purple] and [indigo], similar colors.
///  * [Theme.of], which allows you to select colors from the current theme
///    rather than hard-coding colors in your build methods.
static const MaterialColor deepPurple = MaterialColor(_deepPurplePrimaryValue, <int, Color>{
  50: Color(0xFFEDE7F6),
  100: Color(0xFFD1C4E9),
  200: Color(0xFFB39DDB),
  300: Color(0xFF9575CD),
  400: Color(0xFF7E57C2),
  500: Color(_deepPurplePrimaryValue),
  600: Color(0xFF5E35B1),
  700: Color(0xFF512DA8),
  800: Color(0xFF4527A0),
  900: Color(0xFF311B92),
});