lightBlue constant
MaterialColor
const lightBlue
The light blue primary color and swatch.



Icon(
Icons.widgets,
color: Colors.lightBlue[400],
)
See also:
- lightBlueAccent, the corresponding accent colors.
- blue and cyan, similar colors.
- Theme.of, which allows you to select colors from the current theme rather than hard-coding colors in your build methods.
Implementation
// TODO(framework): Add unit tests to this code snippet.
// https://github.com/flutter/flutter/issues/188530
///
/// ```dart
/// Icon(
/// Icons.widgets,
/// color: Colors.lightBlue[400],
/// )
/// ```
///
/// </callout-box>
///
/// See also:
///
/// * [lightBlueAccent], the corresponding accent colors.
/// * [blue] and [cyan], similar colors.
/// * [Theme.of], which allows you to select colors from the current theme
/// rather than hard-coding colors in your build methods.
static const MaterialColor lightBlue = MaterialColor(_lightBluePrimaryValue, <int, Color>{
50: Color(0xFFE1F5FE),
100: Color(0xFFB3E5FC),
200: Color(0xFF81D4FA),
300: Color(0xFF4FC3F7),
400: Color(0xFF29B6F6),
500: Color(_lightBluePrimaryValue),
600: Color(0xFF039BE5),
700: Color(0xFF0288D1),
800: Color(0xFF0277BD),
900: Color(0xFF01579B),
});