lightBlueAccent constant

MaterialAccentColor const lightBlueAccent

The light blue accent swatch.

Icon(
  Icons.widgets,
  color: Colors.lightBlueAccent[400],
)

See also:

  • lightBlue, the corresponding primary colors.
  • blueAccent and cyanAccent, similar colors.
  • Theme.of, which allows you to select colors from the current theme rather than hard-coding colors in your build methods.

Implementation

// TODO(framework): Add unit tests to this code snippet.
// https://github.com/flutter/flutter/issues/188530
///
/// ```dart
/// Icon(
///   Icons.widgets,
///   color: Colors.lightBlueAccent[400],
/// )
/// ```
///
/// </callout-box>
///
/// See also:
///
///  * [lightBlue], the corresponding primary colors.
///  * [blueAccent] and [cyanAccent], similar colors.
///  * [Theme.of], which allows you to select colors from the current theme
///    rather than hard-coding colors in your build methods.
static const MaterialAccentColor lightBlueAccent =
    MaterialAccentColor(_lightBlueAccentPrimaryValue, <int, Color>{
      100: Color(0xFF80D8FF),
      200: Color(_lightBlueAccentPrimaryValue),
      400: Color(0xFF00B0FF),
      700: Color(0xFF0091EA),
    });