lightGreen constant

MaterialColor const lightGreen

The light green primary color and swatch.

Icon(
  Icons.widgets,
  color: Colors.lightGreen[400],
)

See also:

  • lightGreenAccent, the corresponding accent colors.
  • green and lime, similar colors.
  • Theme.of, which allows you to select colors from the current theme rather than hard-coding colors in your build methods.

Implementation

// TODO(framework): Add unit tests to this code snippet.
// https://github.com/flutter/flutter/issues/188530
///
/// ```dart
/// Icon(
///   Icons.widgets,
///   color: Colors.lightGreen[400],
/// )
/// ```
///
/// </callout-box>
///
/// See also:
///
///  * [lightGreenAccent], the corresponding accent colors.
///  * [green] and [lime], similar colors.
///  * [Theme.of], which allows you to select colors from the current theme
///    rather than hard-coding colors in your build methods.
static const MaterialColor lightGreen = MaterialColor(_lightGreenPrimaryValue, <int, Color>{
  50: Color(0xFFF1F8E9),
  100: Color(0xFFDCEDC8),
  200: Color(0xFFC5E1A5),
  300: Color(0xFFAED581),
  400: Color(0xFF9CCC65),
  500: Color(_lightGreenPrimaryValue),
  600: Color(0xFF7CB342),
  700: Color(0xFF689F38),
  800: Color(0xFF558B2F),
  900: Color(0xFF33691E),
});