limeAccent constant

MaterialAccentColor const limeAccent

The lime accent primary color and swatch.

Icon(
  Icons.widgets,
  color: Colors.limeAccent[400],
)

See also:

  • lime, the corresponding primary colors.
  • lightGreenAccent and yellowAccent, similar colors.
  • Theme.of, which allows you to select colors from the current theme rather than hard-coding colors in your build methods.

Implementation

// TODO(framework): Add unit tests to this code snippet.
// https://github.com/flutter/flutter/issues/188530
///
/// ```dart
/// Icon(
///   Icons.widgets,
///   color: Colors.limeAccent[400],
/// )
/// ```
///
/// </callout-box>
///
/// See also:
///
///  * [lime], the corresponding primary colors.
///  * [lightGreenAccent] and [yellowAccent], similar colors.
///  * [Theme.of], which allows you to select colors from the current theme
///    rather than hard-coding colors in your build methods.
static const MaterialAccentColor limeAccent =
    MaterialAccentColor(_limeAccentPrimaryValue, <int, Color>{
      100: Color(0xFFF4FF81),
      200: Color(_limeAccentPrimaryValue),
      400: Color(0xFFC6FF00),
      700: Color(0xFFAEEA00),
    });