pink constant

MaterialColor const pink

The pink primary color and swatch.

Icon(
  Icons.widgets,
  color: Colors.pink[400],
)

See also:

  • pinkAccent, the corresponding accent colors.
  • red and purple, similar colors.
  • Theme.of, which allows you to select colors from the current theme rather than hard-coding colors in your build methods.

Implementation

// TODO(framework): Add unit tests to this code snippet.
// https://github.com/flutter/flutter/issues/188530
///
/// ```dart
/// Icon(
///   Icons.widgets,
///   color: Colors.pink[400],
/// )
/// ```
///
/// </callout-box>
///
/// See also:
///
///  * [pinkAccent], the corresponding accent colors.
///  * [red] and [purple], similar colors.
///  * [Theme.of], which allows you to select colors from the current theme
///    rather than hard-coding colors in your build methods.
static const MaterialColor pink = MaterialColor(_pinkPrimaryValue, <int, Color>{
  50: Color(0xFFFCE4EC),
  100: Color(0xFFF8BBD0),
  200: Color(0xFFF48FB1),
  300: Color(0xFFF06292),
  400: Color(0xFFEC407A),
  500: Color(_pinkPrimaryValue),
  600: Color(0xFFD81B60),
  700: Color(0xFFC2185B),
  800: Color(0xFFAD1457),
  900: Color(0xFF880E4F),
});