red constant

MaterialColor const red

The red primary color and swatch.

Icon(
  Icons.widgets,
  color: Colors.red[400],
)

See also:

  • redAccent, the corresponding accent colors.
  • deepOrange and pink, similar colors.
  • Theme.of, which allows you to select colors from the current theme rather than hard-coding colors in your build methods.

Implementation

// TODO(framework): Add unit tests to this code snippet.
// https://github.com/flutter/flutter/issues/188530
///
/// ```dart
/// Icon(
///   Icons.widgets,
///   color: Colors.red[400],
/// )
/// ```
///
/// </callout-box>
///
/// See also:
///
///  * [redAccent], the corresponding accent colors.
///  * [deepOrange] and [pink], similar colors.
///  * [Theme.of], which allows you to select colors from the current theme
///    rather than hard-coding colors in your build methods.
static const MaterialColor red = MaterialColor(_redPrimaryValue, <int, Color>{
  50: Color(0xFFFFEBEE),
  100: Color(0xFFFFCDD2),
  200: Color(0xFFEF9A9A),
  300: Color(0xFFE57373),
  400: Color(0xFFEF5350),
  500: Color(_redPrimaryValue),
  600: Color(0xFFE53935),
  700: Color(0xFFD32F2F),
  800: Color(0xFFC62828),
  900: Color(0xFFB71C1C),
});