redAccent constant

MaterialAccentColor const redAccent

The red accent swatch.

Icon(
  Icons.widgets,
  color: Colors.redAccent[400],
)

See also:

  • red, the corresponding primary colors.
  • deepOrangeAccent and pinkAccent, similar colors.
  • Theme.of, which allows you to select colors from the current theme rather than hard-coding colors in your build methods.

Implementation

// TODO(framework): Add unit tests to this code snippet.
// https://github.com/flutter/flutter/issues/188530
///
/// ```dart
/// Icon(
///   Icons.widgets,
///   color: Colors.redAccent[400],
/// )
/// ```
///
/// </callout-box>
///
/// See also:
///
///  * [red], the corresponding primary colors.
///  * [deepOrangeAccent] and [pinkAccent], similar colors.
///  * [Theme.of], which allows you to select colors from the current theme
///    rather than hard-coding colors in your build methods.
static const MaterialAccentColor redAccent = MaterialAccentColor(_redAccentValue, <int, Color>{
  100: Color(0xFFFF8A80),
  200: Color(_redAccentValue),
  400: Color(0xFFFF1744),
  700: Color(0xFFD50000),
});