radius property
The amount of radius for the border of the divider.
If this is null, then DividerThemeData.radius is used. If that is also null, then the default radius of BoxDecoration is used.
Implementation
final BorderRadiusGeometry? radius;
The amount of radius for the border of the divider.
If this is null, then DividerThemeData.radius is used. If that is also null, then the default radius of BoxDecoration is used.
final BorderRadiusGeometry? radius;