currentExtent property
If the FlexibleSpaceBar.title or the FlexibleSpaceBar.background is not null, then this value is used to calculate the relative scale of these elements upon initialization.
Implementation
final double currentExtent;
If the FlexibleSpaceBar.title or the FlexibleSpaceBar.background is not null, then this value is used to calculate the relative scale of these elements upon initialization.
final double currentExtent;