GappedSliderTrackShape constructor
const
GappedSliderTrackShape()
Create a slider track that draws two rectangles with rounded outer edges.
Implementation
const GappedSliderTrackShape();
Create a slider track that draws two rectangles with rounded outer edges.
const GappedSliderTrackShape();