adaptive property

PlatformAdaptiveIcons get adaptive

A set of platform-adaptive Material Design icons.

Provides a convenient way to show a certain set of platform-appropriate icons on Apple platforms.

Use with the Icon class to show specific icons.

This example shows how to create a share icon that uses the material icon named "share" on non-Apple platforms, and the icon named "ios share" on Apple platforms.

Icon(
  Icons.adaptive.share,
)

See also:

Implementation

// TODO(framework): Add unit tests to this code snippet.
// https://github.com/flutter/flutter/issues/188530
///
/// This example shows how to create a share icon that uses the material icon
/// named "share" on non-Apple platforms, and the icon named "ios share" on
/// Apple platforms.
///
/// ```dart
/// Icon(
///   Icons.adaptive.share,
/// )
/// ```
///
/// </callout-box>
///
/// See also:
///
///  * [Icon]
///  * [IconButton]
///  * <https://design.google.com/icons/>
static PlatformAdaptiveIcons get adaptive => const PlatformAdaptiveIcons._();