borderRadius property
The border radius of the containing rectangle. This is effective only if highlightShape is BoxShape.rectangle.
If this is null, it is interpreted as BorderRadius.zero.
Implementation
final BorderRadius? borderRadius;
The border radius of the containing rectangle. This is effective only if highlightShape is BoxShape.rectangle.
If this is null, it is interpreted as BorderRadius.zero.
final BorderRadius? borderRadius;