onSecondaryTapDown property
Called when the user taps down on this part of the material with a secondary button.
See also:
- kSecondaryButton, the button this callback responds to.
Implementation
final GestureTapDownCallback? onSecondaryTapDown;
Called when the user taps down on this part of the material with a secondary button.
See also:
final GestureTapDownCallback? onSecondaryTapDown;