applyThemeToAll property
Flag to apply this theme to all descendant Cupertino widgets.
Certain Cupertino widgets previously didn't use theming, matching past
versions of iOS. For example, CupertinoSwitchs always used
CupertinoColors.systemGreen when active.
Today, however, these widgets can indeed be themed on iOS. Moreover on macOS, the accent color is reflected in these widgets. Turning this flag on ensures that descendant Cupertino widgets will be themed accordingly.
This flag currently applies to the following widgets:
CupertinoSwitch& Switch.adaptive
Defaults to false.
Implementation
@override
bool get applyThemeToAll => super.applyThemeToAll ?? _defaults.applyThemeToAll;