currentDateLabel property
String
get
currentDateLabel
Label indicating that a given date is the current date.
Implementation
String get currentDateLabel;
Label indicating that a given date is the current date.
String get currentDateLabel;