expandedIconTapHint property
String
get
expandedIconTapHint
The semantics hint to describe the tap action on an expanded ExpandIcon.
Implementation
String get expandedIconTapHint => 'Collapse';
The semantics hint to describe the tap action on an expanded ExpandIcon.
String get expandedIconTapHint => 'Collapse';