invalidDateFormatLabel property
String
get
invalidDateFormatLabel
Error message displayed to the user when they have entered a text string in an InputDatePickerFormField that is not in a valid date format.
Implementation
String get invalidDateFormatLabel;