The center of the circular arc, null if begin and end are horizontally or vertically aligned, or if either is null.
Offset? get center { if (begin == null || end == null) { return null; } if (_dirty) { _initialize(); } return _center; }