The radius of the circular arc, null if begin and end are horizontally or vertically aligned, or if either is null.
double? get radius { if (begin == null || end == null) { return null; } if (_dirty) { _initialize(); } return _radius; }