scrollControlDisabledMaxHeightRatio property
The max height constraint ratio for the bottom sheet when isScrollControlled is set to false, no ratio will be applied when isScrollControlled is set to true.
Defaults to 9 / 16.
Implementation
final double scrollControlDisabledMaxHeightRatio;