NavigationDrawer class
Material Design Navigation Drawer component.
On top of Drawers, Navigation drawers offer a persistent and convenient way to switch between primary destinations in an app.
The style for the icons and text are not affected by parent
DefaultTextStyles or IconThemes but rather controlled by parameters or
the NavigationDrawerThemeData.
The children are a list of widgets to be displayed in the drawer. These can be a
mixture of any widgets, but there is special handling for NavigationDrawerDestinations.
They are treated as a group and when one is selected, the onDestinationSelected
is called with the index into the group that corresponds to the selected destination.
This example shows a NavigationDrawer used within a Scaffold
widget. The NavigationDrawer has headline widget, divider widget and three
NavigationDrawerDestination widgets. The initial selectedIndex is 0.
The onDestinationSelected callback changes the selected item's index and displays
a corresponding widget in the body of the Scaffold.
To see it in action, copy and run this code snippet on DartPad.
// Builds an adaptive navigation widget layout. When the screen width is less than
// 450, A [NavigationBar] will be displayed. Otherwise, a [NavigationRail] will be
// displayed on the left side, and also a button to open the [NavigationDrawer].
// All of these navigation widgets are built from an identical list of data.
import 'package:material_ui/material_ui.dart';
/// Flutter code sample for [NavigationDrawer].
void main() => runApp(const NavigationDrawerApp());
class ExampleDestination {
const ExampleDestination(this.label, this.icon, this.selectedIcon);
final String label;
final Widget icon;
final Widget selectedIcon;
}
const List<ExampleDestination> destinations = <ExampleDestination>[
ExampleDestination(
'Messages',
Icon(Icons.widgets_outlined),
Icon(Icons.widgets),
),
ExampleDestination(
'Profile',
Icon(Icons.format_paint_outlined),
Icon(Icons.format_paint),
),
ExampleDestination(
'Settings',
Icon(Icons.settings_outlined),
Icon(Icons.settings),
),
];
class NavigationDrawerApp extends StatelessWidget {
const NavigationDrawerApp({super.key});
@override
Widget build(BuildContext context) {
return const MaterialApp(
debugShowCheckedModeBanner: false,
home: NavigationDrawerExample(),
);
}
}
class NavigationDrawerExample extends StatefulWidget {
const NavigationDrawerExample({super.key});
@override
State<NavigationDrawerExample> createState() =>
_NavigationDrawerExampleState();
}
class _NavigationDrawerExampleState extends State<NavigationDrawerExample> {
final GlobalKey<ScaffoldState> scaffoldKey = GlobalKey<ScaffoldState>();
int screenIndex = 0;
late bool showNavigationDrawer;
void handleScreenChanged(int selectedScreen) {
setState(() {
screenIndex = selectedScreen;
});
}
void openDrawer() {
scaffoldKey.currentState!.openEndDrawer();
}
Widget buildBottomBarScaffold() {
return Scaffold(
body: Center(
child: Column(
mainAxisAlignment: .spaceEvenly,
children: <Widget>[Text('Page Index = $screenIndex')],
),
),
bottomNavigationBar: NavigationBar(
selectedIndex: screenIndex,
onDestinationSelected: (int index) {
setState(() {
screenIndex = index;
});
},
destinations: destinations.map((ExampleDestination destination) {
return NavigationDestination(
label: destination.label,
icon: destination.icon,
selectedIcon: destination.selectedIcon,
tooltip: destination.label,
);
}).toList(),
),
);
}
Widget buildDrawerScaffold(BuildContext context) {
return Scaffold(
key: scaffoldKey,
body: SafeArea(
bottom: false,
top: false,
child: Row(
children: <Widget>[
Padding(
padding: const .symmetric(horizontal: 5),
child: NavigationRail(
minWidth: 50,
destinations: destinations.map((
ExampleDestination destination,
) {
return NavigationRailDestination(
label: Text(destination.label),
icon: destination.icon,
selectedIcon: destination.selectedIcon,
);
}).toList(),
selectedIndex: screenIndex,
useIndicator: true,
onDestinationSelected: (int index) {
setState(() {
screenIndex = index;
});
},
),
),
const VerticalDivider(thickness: 1, width: 1),
Expanded(
child: Column(
mainAxisAlignment: .spaceEvenly,
children: <Widget>[
Text('Page Index = $screenIndex'),
ElevatedButton(
onPressed: openDrawer,
child: const Text('Open Drawer'),
),
],
),
),
],
),
),
endDrawer: NavigationDrawer(
onDestinationSelected: handleScreenChanged,
selectedIndex: screenIndex,
children: <Widget>[
Padding(
padding: const .fromLTRB(28, 16, 16, 10),
child: Text(
'Header',
style: Theme.of(context).textTheme.titleSmall,
),
),
...destinations.map((ExampleDestination destination) {
return NavigationDrawerDestination(
label: Text(destination.label),
icon: destination.icon,
selectedIcon: destination.selectedIcon,
);
}),
const Padding(padding: .fromLTRB(28, 16, 28, 10), child: Divider()),
],
),
);
}
@override
void didChangeDependencies() {
super.didChangeDependencies();
showNavigationDrawer = MediaQuery.widthOf(context) >= 450;
}
@override
Widget build(BuildContext context) {
return showNavigationDrawer
? buildDrawerScaffold(context)
: buildBottomBarScaffold();
}
}
See also:
- Scaffold.drawer, where one specifies a Drawer so that it can be shown.
- Scaffold.of, to obtain the current ScaffoldState, which manages the display and animation of the drawer.
- ScaffoldState.openDrawer, which displays its Drawer, if any.
- material.io/design/components/navigation-drawer.html
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- NavigationDrawer
Constructors
-
Creates a Material Design Navigation Drawer component.
const
Properties
- backgroundColor → Color?
-
The background color of the Material that holds the NavigationDrawer's
contents.
final
-
children
→ List<
Widget> -
Defines the appearance of the items within the navigation drawer.
final
- elevation → double?
-
The elevation of the NavigationDrawer itself.
final
-
A widget to display at the bottom of the layout.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- header → Widget?
-
A widget to display at the top of the layout.
final
- indicatorColor → Color?
-
The color of the indicatorShape when this destination is selected.
final
- indicatorShape → ShapeBorder?
-
The shape of the selected indicator.
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
-
onDestinationSelected
→ ValueChanged<
int> ? -
Called when one of the
NavigationDrawerDestinationchildren is selected.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectedIndex → int?
-
The index into destinations for the current selected
NavigationDrawerDestinationor null if no destination is selected.final - shadowColor → Color?
-
The color used for the drop shadow to indicate elevation.
final
- surfaceTintColor → Color?
-
The surface tint of the Material that holds the NavigationDrawer's
contents.
final
- tilePadding → EdgeInsetsGeometry
-
Defines the padding for
NavigationDrawerDestinationwidgets (Drawer items).final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited