NavigationRailLabelType enum
Defines the behavior of the labels of a NavigationRail.
See also:
NavigationRail
Values
- none → const NavigationRailLabelType
-
Only the
NavigationRailDestinations are shown. - selected → const NavigationRailLabelType
-
Only the selected
NavigationRailDestinationwill show its label.The label will animate in and out as new
NavigationRailDestinations are selected. - all → const NavigationRailLabelType
-
All
NavigationRailDestinations will show their label.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
NavigationRailLabelType> - A constant List of the values in this enum, in order of their declaration.