RadioListTile<T> class

A ListTile with a Radio. In other words, a radio button with a label.

The entire list tile is interactive: tapping anywhere in the tile selects the radio button.

This widget typically has a RadioGroup ancestor, which takes in a RadioGroup.groupValue, and the RadioListTile under it with matching value will be selected.

The title, subtitle, isThreeLine, and dense properties are like those of the same name on ListTile.

The selected property on this widget is similar to the ListTile.selected property. The fillColor in the selected state is used for the selected item's text color. If it is null, the activeColor is used.

This widget does not coordinate the selected state and the checked state; to have the list tile appear selected when the radio button is the selected radio button, set selected to true when value matches RadioGroup.groupValue.

The radio button is shown on the left by default in left-to-right languages (i.e. the leading edge). This can be changed using controlAffinity. The secondary widget is placed on the opposite side. This maps to the ListTile.leading and ListTile.trailing properties of ListTile.

This widget requires a Material widget ancestor in the tree to paint itself on, which is typically provided by the app's Scaffold. The tileColor, and selectedTileColor are not painted by the RadioListTile itself but by the Material widget ancestor. In this case, one can wrap a Material widget around the RadioListTile, e.g.:

const ColoredBox(
  color: Colors.green,
  child: Material(
    child: RadioListTile<Meridiem>(
      tileColor: Colors.red,
      title: Text('AM'),
      value: Meridiem.am,
    ),
  ),
)

Performance considerations when wrapping RadioListTile with Material

Wrapping a large number of RadioListTiles individually with Materials is expensive. Consider only wrapping the RadioListTiles that require it or include a common Material ancestor where possible.

RadioListTile sample

This widget shows a pair of radio buttons that control the _character field. The field is of the type SingingCharacter, an enum.

To see it in action, copy and run this code snippet on DartPad.

import 'package:material_ui/material_ui.dart';

/// Flutter code sample for [RadioListTile].

void main() => runApp(const RadioListTileApp());

class RadioListTileApp extends StatelessWidget {
  const RadioListTileApp({super.key});

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      home: Scaffold(
        appBar: AppBar(title: const Text('RadioListTile Sample')),
        body: const RadioListTileExample(),
      ),
    );
  }
}

enum SingingCharacter { lafayette, jefferson }

class RadioListTileExample extends StatefulWidget {
  const RadioListTileExample({super.key});

  @override
  State<RadioListTileExample> createState() => _RadioListTileExampleState();
}

class _RadioListTileExampleState extends State<RadioListTileExample> {
  SingingCharacter? _character = .lafayette;

  @override
  Widget build(BuildContext context) {
    return RadioGroup<SingingCharacter>(
      groupValue: _character,
      onChanged: (SingingCharacter? value) {
        setState(() {
          _character = value;
        });
      },
      child: const Column(
        children: <Widget>[
          RadioListTile<SingingCharacter>(
            title: Text('Lafayette'),
            value: SingingCharacter.lafayette,
          ),
          RadioListTile<SingingCharacter>(
            title: Text('Thomas Jefferson'),
            value: SingingCharacter.jefferson,
          ),
        ],
      ),
    );
  }
}

This sample demonstrates how RadioListTile positions the radio widget relative to the text in different configurations.

To see it in action, copy and run this code snippet on DartPad.

import 'package:material_ui/material_ui.dart';

/// Flutter code sample for [RadioListTile].

void main() => runApp(const RadioListTileApp());

class RadioListTileApp extends StatelessWidget {
  const RadioListTileApp({super.key});

  @override
  Widget build(BuildContext context) {
    return const MaterialApp(home: RadioListTileExample());
  }
}

enum Groceries { pickles, tomato, lettuce }

class RadioListTileExample extends StatefulWidget {
  const RadioListTileExample({super.key});

  @override
  State<RadioListTileExample> createState() => _RadioListTileExampleState();
}

class _RadioListTileExampleState extends State<RadioListTileExample> {
  Groceries? _groceryItem = .pickles;

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(title: const Text('RadioListTile Sample')),
      body: RadioGroup<Groceries>(
        groupValue: _groceryItem,
        onChanged: (Groceries? value) {
          setState(() {
            _groceryItem = value;
          });
        },
        child: const Column(
          children: <Widget>[
            RadioListTile<Groceries>(
              value: Groceries.pickles,
              title: Text('Pickles'),
              subtitle: Text('Supporting text'),
            ),
            RadioListTile<Groceries>(
              value: Groceries.tomato,
              title: Text('Tomato'),
              subtitle: Text(
                'Longer supporting text to demonstrate how the text wraps and the radio is centered vertically with the text.',
              ),
            ),
            RadioListTile<Groceries>(
              value: Groceries.lettuce,
              title: Text('Lettuce'),
              subtitle: Text(
                "Longer supporting text to demonstrate how the text wraps and how setting 'RadioListTile.isThreeLine = true' aligns the radio to the top vertically with the text.",
              ),
              isThreeLine: true,
            ),
          ],
        ),
      ),
    );
  }
}

Semantics in RadioListTile

Since the entirety of the RadioListTile is interactive, it should represent itself as a single interactive entity.

To do so, a RadioListTile widget wraps its children with a MergeSemantics widget. MergeSemantics will attempt to merge its descendant Semantics nodes into one node in the semantics tree. Therefore, RadioListTile will throw an error if any of its children requires its own Semantics node.

For example, you cannot nest a RichText widget as a descendant of RadioListTile. RichText has an embedded gesture recognizer that requires its own Semantics node, which directly conflicts with RadioListTile's desire to merge all its descendants' semantic nodes into one. Therefore, it may be necessary to create a custom radio tile widget to accommodate similar use cases.

Radio list tile semantics sample

Here is an example of a custom labeled radio widget, called LinkedLabelRadio, that includes an interactive RichText widget that handles tap gestures.

To see it in action, copy and run this code snippet on DartPad.

import 'package:flutter/gestures.dart';

import 'package:material_ui/material_ui.dart';

/// Flutter code sample for custom labeled radio.

void main() => runApp(const LabeledRadioApp());

class LabeledRadioApp extends StatelessWidget {
  const LabeledRadioApp({super.key});

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      home: Scaffold(
        appBar: AppBar(title: const Text('Custom Labeled Radio Sample')),
        body: const LabeledRadioExample(),
      ),
    );
  }
}

class LinkedLabelRadio extends StatelessWidget {
  const LinkedLabelRadio({
    super.key,
    required this.label,
    required this.padding,
    required this.value,
  });

  final String label;
  final EdgeInsets padding;
  final bool value;

  @override
  Widget build(BuildContext context) {
    return Padding(
      padding: padding,
      child: Row(
        children: <Widget>[
          Radio<bool>(value: value),
          RichText(
            text: TextSpan(
              text: label,
              style: TextStyle(
                color: Theme.of(context).colorScheme.primary,
                decoration: TextDecoration.underline,
              ),
              recognizer: TapGestureRecognizer()
                ..onTap = () {
                  debugPrint('Label has been tapped.');
                },
            ),
          ),
        ],
      ),
    );
  }
}

class LabeledRadioExample extends StatefulWidget {
  const LabeledRadioExample({super.key});

  @override
  State<LabeledRadioExample> createState() => _LabeledRadioExampleState();
}

class _LabeledRadioExampleState extends State<LabeledRadioExample> {
  bool _isRadioSelected = false;

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      body: RadioGroup<bool>(
        groupValue: _isRadioSelected,
        onChanged: (bool? newValue) {
          setState(() {
            _isRadioSelected = newValue!;
          });
        },
        child: const Column(
          mainAxisAlignment: .center,
          children: <Widget>[
            LinkedLabelRadio(
              label: 'First tappable label text',
              padding: .symmetric(horizontal: 5.0),
              value: true,
            ),
            LinkedLabelRadio(
              label: 'Second tappable label text',
              padding: .symmetric(horizontal: 5.0),
              value: false,
            ),
          ],
        ),
      ),
    );
  }
}

RadioListTile isn't exactly what I want

If the way RadioListTile pads and positions its elements isn't quite what you're looking for, you can create custom labeled radio widgets by combining Radio with other widgets, such as Text, Padding and InkWell.

Custom radio list tile sample

Here is an example of a custom LabeledRadio widget, but you can easily make your own configurable widget.

To see it in action, copy and run this code snippet on DartPad.

import 'package:material_ui/material_ui.dart';

/// Flutter code sample for custom labeled radio.

void main() => runApp(const LabeledRadioApp());

class LabeledRadioApp extends StatelessWidget {
  const LabeledRadioApp({super.key});

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      home: Scaffold(
        appBar: AppBar(title: const Text('Custom Labeled Radio Sample')),
        body: const LabeledRadioExample(),
      ),
    );
  }
}

class LabeledRadio extends StatelessWidget {
  const LabeledRadio({
    super.key,
    required this.label,
    required this.padding,
    required this.value,
  });

  final String label;
  final EdgeInsets padding;
  final bool value;

  @override
  Widget build(BuildContext context) {
    return InkWell(
      onTap: () {
        RadioGroup.maybeOf<bool>(context)?.onChanged(value);
      },
      child: Padding(
        padding: padding,
        child: Row(
          children: <Widget>[
            Radio<bool>(value: value),
            Text(label),
          ],
        ),
      ),
    );
  }
}

class LabeledRadioExample extends StatefulWidget {
  const LabeledRadioExample({super.key});

  @override
  State<LabeledRadioExample> createState() => _LabeledRadioExampleState();
}

class _LabeledRadioExampleState extends State<LabeledRadioExample> {
  bool _isRadioSelected = false;

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      body: RadioGroup<bool>(
        groupValue: _isRadioSelected,
        onChanged: (bool? newValue) {
          setState(() {
            _isRadioSelected = newValue!;
          });
        },
        child: const Column(
          mainAxisAlignment: .center,
          children: <LabeledRadio>[
            LabeledRadio(
              label: 'This is the first label text',
              padding: .symmetric(horizontal: 5.0),
              value: true,
            ),
            LabeledRadio(
              label: 'This is the second label text',
              padding: .symmetric(horizontal: 5.0),
              value: false,
            ),
          ],
        ),
      ),
    );
  }
}

See also:

Inheritance

Constructors

RadioListTile({Key? key, required T value, @Deprecated('Use a RadioGroup ancestor to manage group value instead. ' 'This feature was deprecated after v3.32.0-0.0.pre.') T? groupValue, @Deprecated('Use RadioGroup to handle value change instead. ' 'This feature was deprecated after v3.32.0-0.0.pre.') ValueChanged<T?>? onChanged, MouseCursor? mouseCursor, bool toggleable = false, Color? activeColor, WidgetStateProperty<Color?>? fillColor, Color? hoverColor, WidgetStateProperty<Color?>? overlayColor, double? splashRadius, MaterialTapTargetSize? materialTapTargetSize, Widget? title, Widget? subtitle, bool? isThreeLine, bool? dense, Widget? secondary, bool selected = false, ListTileControlAffinity? controlAffinity, bool autofocus = false, EdgeInsetsGeometry? contentPadding, ShapeBorder? shape, Color? tileColor, Color? selectedTileColor, VisualDensity? visualDensity, FocusNode? focusNode, WidgetStatesController? statesController, ValueChanged<bool>? onFocusChange, bool? enableFeedback, double? horizontalTitleGap, double? minVerticalPadding, double? minLeadingWidth, double? minTileHeight, double radioScaleFactor = 1.0, ListTileTitleAlignment? titleAlignment, bool? enabled, bool internalAddSemanticForOnTap = false, WidgetStateProperty<Color?>? radioBackgroundColor, BorderSide? radioSide, WidgetStateProperty<double?>? radioInnerRadius})
Creates a combination of a list tile and a radio button.
const
RadioListTile.adaptive({Key? key, required T value, @Deprecated('Use a RadioGroup ancestor to manage group value instead. ' 'This feature was deprecated after v3.32.0-0.0.pre.') T? groupValue, @Deprecated('Use RadioGroup to handle value change instead. ' 'This feature was deprecated after v3.32.0-0.0.pre.') ValueChanged<T?>? onChanged, MouseCursor? mouseCursor, bool toggleable = false, Color? activeColor, WidgetStateProperty<Color?>? fillColor, Color? hoverColor, WidgetStateProperty<Color?>? overlayColor, double? splashRadius, MaterialTapTargetSize? materialTapTargetSize, Widget? title, Widget? subtitle, bool? isThreeLine, bool? dense, Widget? secondary, bool selected = false, ListTileControlAffinity? controlAffinity, bool autofocus = false, EdgeInsetsGeometry? contentPadding, ShapeBorder? shape, Color? tileColor, Color? selectedTileColor, VisualDensity? visualDensity, FocusNode? focusNode, WidgetStatesController? statesController, ValueChanged<bool>? onFocusChange, bool? enableFeedback, double? horizontalTitleGap, double? minVerticalPadding, double? minLeadingWidth, double? minTileHeight, double radioScaleFactor = 1.0, bool? enabled, bool useCupertinoCheckmarkStyle = false, ListTileTitleAlignment? titleAlignment, bool internalAddSemanticForOnTap = false, WidgetStateProperty<Color?>? radioBackgroundColor, BorderSide? radioSide, WidgetStateProperty<double?>? radioInnerRadius})
Creates a combination of a list tile and a platform adaptive radio.
const

Properties

activeColor Color?
The color to use when this radio button is selected.
final
autofocus bool
True if this widget will be selected as the initial focus when no other node in its scope is currently focused.
final
checked bool
Whether this radio button is checked.
no setter
contentPadding EdgeInsetsGeometry?
Defines the insets surrounding the contents of the tile.
final
controlAffinity ListTileControlAffinity?
Where to place the control relative to the text.
final
dense bool?
Whether this list tile is part of a vertically dense list.
final
enabled bool?
Whether this widget is interactable.
final
enableFeedback bool?
Whether detected gestures should provide acoustic and/or haptic feedback.
final
fillColor WidgetStateProperty<Color?>?
The color that fills the radio button.
final
focusNode FocusNode?
An optional focus node to use as the focus node for this widget.
final
groupValue → T?
The currently selected value for this group of radio buttons.
final
hashCode int
The hash code for this object.
no setterinherited
horizontalTitleGap double?
The horizontal gap between the titles and the leading/trailing widgets.
final
hoverColor Color?
The color for the radio's Material when a pointer is hovering over it.
final
internalAddSemanticForOnTap bool
Whether to add button:true to the semantics if onTap is provided. This is a temporary flag to help changing the behavior of ListTile onTap semantics.
final
isThreeLine bool?
Whether this list tile is intended to display three lines of text.
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
materialTapTargetSize MaterialTapTargetSize?
Configures the minimum size of the tap target.
final
minLeadingWidth double?
The minimum width allocated for the ListTile.leading widget.
final
minTileHeight double?
The minimum height allocated for the ListTile widget.
final
minVerticalPadding double?
The minimum padding on the top and bottom of the title and subtitle widgets.
final
mouseCursor MouseCursor?
The cursor for a mouse pointer when it enters or is hovering over the widget.
final
onChanged ValueChanged<T?>?
Called when the user selects this radio button.
final
onFocusChange ValueChanged<bool>?
Handler called when the focus changes.
final
overlayColor WidgetStateProperty<Color?>?
The color for the radio's Material.
final
radioBackgroundColor WidgetStateProperty<Color?>?
The color of the background of the radio button, in all WidgetStates.
final
radioInnerRadius WidgetStateProperty<double?>?
The radius of the inner circle of the radio button, in all WidgetStates.
final
radioScaleFactor double
Controls the scaling factor applied to the Radio within the RadioListTile.
final
radioSide BorderSide?
The side for the circular border of the radio button, in all WidgetStates.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secondary Widget?
A widget to display on the opposite side of the tile from the radio button.
final
selected bool
Whether to render icons and text in the activeColor.
final
selectedTileColor Color?
If non-null, defines the background color when RadioListTile.selected is true.
final
shape ShapeBorder?
If specified, shape defines the shape of the RadioListTile's InkWell border.
final
splashRadius double?
The splash radius of the circular Material ink response.
final
statesController WidgetStatesController?
Controls the interactive states of the backing ListTile.
final
subtitle Widget?
Additional content displayed below the title.
final
tileColor Color?
If specified, defines the background color for RadioListTile when RadioListTile.selected is false.
final
title Widget?
The primary content of the list tile.
final
titleAlignment ListTileTitleAlignment?
Defines how ListTile.leading and ListTile.trailing are vertically aligned relative to the ListTile's titles (ListTile.title and ListTile.subtitle).
final
toggleable bool
Set to true if this radio list tile is allowed to be returned to an indeterminate state by selecting it again when selected.
final
useCupertinoCheckmarkStyle bool
Whether to use the checkbox style for the CupertinoRadio control.
final
value → T
The value represented by this radio button.
final
visualDensity VisualDensity?
Defines how compact the list tile's layout will be.
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<RadioListTile<T>>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited