useCupertinoCheckmarkStyle property
Whether to use the checkbox style for the CupertinoRadio control.
Only usable under the RadioListTile.adaptive constructor. If set to
true, on Apple platforms the radio button will appear as an iOS styled
checkmark. Controls the CupertinoRadio through
CupertinoRadio.useCheckmarkStyle.
Defaults to false.
Implementation
final bool useCupertinoCheckmarkStyle;