onStatusChange property
Called to get the current status of the RefreshIndicator to update the UI as needed. This is an optional parameter, used to fine tune app cases.
Implementation
final ValueChanged<RefreshIndicatorStatus?>? onStatusChange;
Called to get the current status of the RefreshIndicator to update the UI as needed. This is an optional parameter, used to fine tune app cases.
final ValueChanged<RefreshIndicatorStatus?>? onStatusChange;