thumbVisibility property
Indicates that the scrollbar thumb should be visible, even when a scroll is not underway.
For more information, see RawScrollbar.thumbVisibility.
If this property is null, then ScrollbarThemeData.thumbVisibility of ThemeData.scrollbarTheme is used. If that is also null, the default value is false.
If the thumb visibility is related to the scrollbar's material state, use the global ScrollbarThemeData.thumbVisibility or override the sub-tree's theme data.
Implementation
// TODO(dkwingsmt): Migrate the doc back to macro
// flutter.widgets.Scrollbar.thumbVisibility
// https://github.com/flutter/flutter/issues/189629
///
/// If this property is null, then [ScrollbarThemeData.thumbVisibility] of
/// [ThemeData.scrollbarTheme] is used. If that is also null, the default value
/// is false.
///
/// If the thumb visibility is related to the scrollbar's material state,
/// use the global [ScrollbarThemeData.thumbVisibility] or override the
/// sub-tree's theme data.
final bool? thumbVisibility;