viewLeading property
An optional widget to display before the text input field when the search view is open.
Typically the viewLeading widget is an Icon or an IconButton.
Defaults to a back button which pops the view.
Implementation
final Widget? viewLeading;