elevation property
The elevation of the search bar's Material.
If null, the value of SearchBarThemeData.elevation will be used. If this is also null, then default value is 6.0.
Implementation
final WidgetStateProperty<double?>? elevation;
The elevation of the search bar's Material.
If null, the value of SearchBarThemeData.elevation will be used. If this is also null, then default value is 6.0.
final WidgetStateProperty<double?>? elevation;