textStyle property
The style to use for the text being edited.
If null, defaults to the bodyLarge text style from the current Theme.
The default text color is ColorScheme.onSurface.
Implementation
final WidgetStateProperty<TextStyle?>? textStyle;
The style to use for the text being edited.
If null, defaults to the bodyLarge text style from the current Theme.
The default text color is ColorScheme.onSurface.
final WidgetStateProperty<TextStyle?>? textStyle;