isOpen property
bool
get
isOpen
Whether or not the associated search view is currently open.
Implementation
bool get isOpen {
assert(isAttached);
return _anchor!._viewIsOpen;
}
Whether or not the associated search view is currently open.
bool get isOpen {
assert(isAttached);
return _anchor!._viewIsOpen;
}