selected property
bool
get
selected
Whether or not this chip is selected.
If onSelected is not null, this value will be used to determine if the select check mark will be shown or not.
Defaults to false.
Implementation
bool get selected;