controller property
An object that can be used to control the position to which this scroll view is scrolled.
To control the initial scroll offset of the scroll view, provide a controller with its ScrollController.initialScrollOffset property set.
Implementation
final ScrollController? controller;