headerPadding property
The padding around the header row in both StepperType.vertical and StepperType.horizontal steppers.
Defaults to to EdgeInsets.symmetric(horizontal: 24.0).
Implementation
final EdgeInsetsGeometry? headerPadding;
The padding around the header row in both StepperType.vertical and StepperType.horizontal steppers.
Defaults to to EdgeInsets.symmetric(horizontal: 24.0).
final EdgeInsetsGeometry? headerPadding;