spellCheckConfiguration property

SpellCheckConfiguration? spellCheckConfiguration
final

Configuration that details how spell check should be performed.

Specifies the SpellCheckService used to spell check text input and the TextStyle used to style text with misspelled words.

Spell check is disabled for password input, including when obscureText is true, keyboardType is TextInputType.visiblePassword, or autofillHints contains AutofillHints.password or AutofillHints.newPassword.

If the SpellCheckService is left null, spell check is disabled by default unless the DefaultSpellCheckService is supported, in which case it is used. It is currently supported only on Android and iOS.

If this configuration is left null, then spell check is disabled by default.

If SpellCheckConfiguration.misspelledTextStyle is not specified in this configuration, then materialMisspelledTextStyle is used by default.

Implementation

final SpellCheckConfiguration? spellCheckConfiguration;