TextSelectionTheme constructor
const
TextSelectionTheme({
- Key? key,
- required TextSelectionThemeData data,
- required Widget child,
Creates a text selection theme widget that specifies the text selection properties for all widgets below it in the widget tree.
Implementation
const TextSelectionTheme({super.key, required this.data, required this._child})
: // See `get child` override below.
super(child: const _NullWidget());