switchToInputEntryModeIcon property
The optional switchToInputEntryModeIcon argument can be used to customize the input method icon that is shown when the TimePickerEntryMode is TimePickerEntryMode.dial.
Defaults to an Icon widget with Icons.keyboard_outlined as icon.
Implementation
final Icon? switchToInputEntryModeIcon;