switchToTimerEntryModeIcon property
The optional switchToTimerEntryModeIcon argument can be used to customize the input method icon that is shown when the TimePickerEntryMode is TimePickerEntryMode.input.
Defaults to an Icon widget with Icons.access_time as icon.
Implementation
final Icon? switchToTimerEntryModeIcon;