verticalDirection property
If direction is Axis.vertical, this parameter determines whether to lay out the buttons starting from the first or last child from top to bottom.
Implementation
final VerticalDirection verticalDirection;
If direction is Axis.vertical, this parameter determines whether to lay out the buttons starting from the first or last child from top to bottom.
final VerticalDirection verticalDirection;