borderWidth property
The width of the border surrounding each toggle button.
This applies to both the greater surrounding border, as well as the borders dividing each toggle button.
To render a hairline border (one physical pixel), set borderWidth to 0.0. See BorderSide.width for more details on hairline borders.
Implementation
final double? borderWidth;