debugFocusChanges top-level property

bool debugFocusChanges
getter/setter pair

Setting to true will cause extensive logging to occur when focus changes occur.

Can be used to debug focus issues: each time the focus changes, the focus tree will be printed and requests for focus and other focus operations will be logged.

This has no effect in release builds.

See also:

Implementation

bool debugFocusChanges = false;