data property
Specifies the background color, label text style, icon theme, and label
type values for descendant NavigationBar widgets.
Implementation
@override
final NavigationBarThemeData data;
Specifies the background color, label text style, icon theme, and label
type values for descendant NavigationBar widgets.
@override
final NavigationBarThemeData data;