tooltipTrigger property
Controls which gesture triggers the tooltip popover.
If null, Flutter's platform default is used (long press on mobile, long press and hover on desktop).
For navigation destinations in this package, TooltipTriggerMode.tap is mapped to a secondary tap (such as right click) so the primary tap can continue to activate navigation.
Implementation
final TooltipTriggerMode? tooltipTrigger;