data property
Specifies the background color, elevation, label text style, icon theme, group alignment, and label type and border values for descendant NavigationRail widgets.
Implementation
@override
final NavigationRailThemeData data;
Specifies the background color, elevation, label text style, icon theme, group alignment, and label type and border values for descendant NavigationRail widgets.
@override
final NavigationRailThemeData data;