margin property
Applies a margin around each navigation item in the rail.
This creates space between adjacent destination items and between items and the rail edges. Defaults to EdgeInsets.zero.
Implementation
final EdgeInsetsGeometry? margin;
Applies a margin around each navigation item in the rail.
This creates space between adjacent destination items and between items and the rail edges. Defaults to EdgeInsets.zero.
final EdgeInsetsGeometry? margin;