selectedLabelTextStyle property

  1. @override
  2. @Deprecated("Material 2 is deprecated in Flutter and will be removed in v6.0.0 of this package. " "Migrate to Material 3 by relying on the default M3 behavior.")
TextStyle? selectedLabelTextStyle
final

The style to merge with the default text style for NavigationRailDestination labels, when the destination is selected.

Implementation

@override
// TODO(v6.0.0): Remove to deprecate M2.
@Deprecated(
  "Material 2 is deprecated in Flutter and will be removed in v6.0.0 of this package. "
  "Migrate to Material 3 by relying on the default M3 behavior.",
)
final TextStyle? selectedLabelTextStyle;