showLabelsWhenCollapsed property
Whether labels are shown while the rail is collapsed and labelType is NavigationRailLabelType.none.
Implementation
final bool? showLabelsWhenCollapsed;
Whether labels are shown while the rail is collapsed and labelType is NavigationRailLabelType.none.
final bool? showLabelsWhenCollapsed;