cyan constant
MaterialColor
const cyan
The cyan primary color and swatch.




Icon(
Icons.widgets,
color: Colors.cyan[400],
)
See also:
- cyanAccent, the corresponding accent colors.
- lightBlue, teal, and blueGrey, similar colors.
- Theme.of, which allows you to select colors from the current theme rather than hard-coding colors in your build methods.
Implementation
// TODO(framework): Add unit tests to this code snippet.
// https://github.com/flutter/flutter/issues/188530
///
/// ```dart
/// Icon(
/// Icons.widgets,
/// color: Colors.cyan[400],
/// )
/// ```
///
/// </callout-box>
///
/// See also:
///
/// * [cyanAccent], the corresponding accent colors.
/// * [lightBlue], [teal], and [blueGrey], similar colors.
/// * [Theme.of], which allows you to select colors from the current theme
/// rather than hard-coding colors in your build methods.
static const MaterialColor cyan = MaterialColor(_cyanPrimaryValue, <int, Color>{
50: Color(0xFFE0F7FA),
100: Color(0xFFB2EBF2),
200: Color(0xFF80DEEA),
300: Color(0xFF4DD0E1),
400: Color(0xFF26C6DA),
500: Color(_cyanPrimaryValue),
600: Color(0xFF00ACC1),
700: Color(0xFF0097A7),
800: Color(0xFF00838F),
900: Color(0xFF006064),
});