deepOrange constant
MaterialColor
const deepOrange
The deep orange primary color and swatch.




Icon(
Icons.widgets,
color: Colors.deepOrange[400],
)
See also:
- deepOrangeAccent, the corresponding accent colors.
- orange, red, and brown, similar colors.
- Theme.of, which allows you to select colors from the current theme rather than hard-coding colors in your build methods.
Implementation
// TODO(framework): Add unit tests to this code snippet.
// https://github.com/flutter/flutter/issues/188530
///
/// ```dart
/// Icon(
/// Icons.widgets,
/// color: Colors.deepOrange[400],
/// )
/// ```
///
/// </callout-box>
///
/// See also:
///
/// * [deepOrangeAccent], the corresponding accent colors.
/// * [orange], [red], and [brown], similar colors.
/// * [Theme.of], which allows you to select colors from the current theme
/// rather than hard-coding colors in your build methods.
static const MaterialColor deepOrange = MaterialColor(_deepOrangePrimaryValue, <int, Color>{
50: Color(0xFFFBE9E7),
100: Color(0xFFFFCCBC),
200: Color(0xFFFFAB91),
300: Color(0xFFFF8A65),
400: Color(0xFFFF7043),
500: Color(_deepOrangePrimaryValue),
600: Color(0xFFF4511E),
700: Color(0xFFE64A19),
800: Color(0xFFD84315),
900: Color(0xFFBF360C),
});