indigo constant
MaterialColor
const indigo
The indigo primary color and swatch.



Icon(
Icons.widgets,
color: Colors.indigo[400],
)
See also:
- indigoAccent, the corresponding accent colors.
- blue and deepPurple, similar colors.
- Theme.of, which allows you to select colors from the current theme rather than hard-coding colors in your build methods.
Implementation
// TODO(framework): Add unit tests to this code snippet.
// https://github.com/flutter/flutter/issues/188530
///
/// ```dart
/// Icon(
/// Icons.widgets,
/// color: Colors.indigo[400],
/// )
/// ```
///
/// </callout-box>
///
/// See also:
///
/// * [indigoAccent], the corresponding accent colors.
/// * [blue] and [deepPurple], similar colors.
/// * [Theme.of], which allows you to select colors from the current theme
/// rather than hard-coding colors in your build methods.
static const MaterialColor indigo = MaterialColor(_indigoPrimaryValue, <int, Color>{
50: Color(0xFFE8EAF6),
100: Color(0xFFC5CAE9),
200: Color(0xFF9FA8DA),
300: Color(0xFF7986CB),
400: Color(0xFF5C6BC0),
500: Color(_indigoPrimaryValue),
600: Color(0xFF3949AB),
700: Color(0xFF303F9F),
800: Color(0xFF283593),
900: Color(0xFF1A237E),
});