lime constant
MaterialColor
const lime
The lime primary color and swatch.



Icon(
Icons.widgets,
color: Colors.lime[400],
)
See also:
- limeAccent, the corresponding accent colors.
- lightGreen and yellow, similar colors.
- Theme.of, which allows you to select colors from the current theme rather than hard-coding colors in your build methods.
Implementation
// TODO(framework): Add unit tests to this code snippet.
// https://github.com/flutter/flutter/issues/188530
///
/// ```dart
/// Icon(
/// Icons.widgets,
/// color: Colors.lime[400],
/// )
/// ```
///
/// </callout-box>
///
/// See also:
///
/// * [limeAccent], the corresponding accent colors.
/// * [lightGreen] and [yellow], similar colors.
/// * [Theme.of], which allows you to select colors from the current theme
/// rather than hard-coding colors in your build methods.
static const MaterialColor lime = MaterialColor(_limePrimaryValue, <int, Color>{
50: Color(0xFFF9FBE7),
100: Color(0xFFF0F4C3),
200: Color(0xFFE6EE9C),
300: Color(0xFFDCE775),
400: Color(0xFFD4E157),
500: Color(_limePrimaryValue),
600: Color(0xFFC0CA33),
700: Color(0xFFAFB42B),
800: Color(0xFF9E9D24),
900: Color(0xFF827717),
});