Drawer class
A Material Design panel that slides in horizontally from the edge of a Scaffold to show navigation links in an application.
There is a Material 3 version of this component, NavigationDrawer, that's preferred for applications that are configured for Material 3 (see ThemeData.useMaterial3).
Learn more about Drawer on the Flutter YouTube channel.
Drawers are typically used with the Scaffold.drawer property. The child of the drawer is usually a ListView whose first child is a DrawerHeader that displays status information about the current user. The remaining drawer children are often constructed with ListTiles, often concluding with an AboutListTile.
The AppBar automatically displays an appropriate IconButton to show the Drawer when a Drawer is available in the Scaffold. The Scaffold automatically handles the edge-swipe gesture to show the drawer.
Updating to NavigationDrawer
There is a Material 3 version of this component, NavigationDrawer,
that's preferred for applications that are configured for Material 3
(see ThemeData.useMaterial3). The NavigationDrawer widget's visual
are a little bit different, see the Material 3 spec at
m3.material.io/components/navigation-drawer/overview for
more details. While the Drawer widget can have only one child, the
NavigationDrawer widget can have a list of widgets, which typically contains
NavigationDrawerDestination widgets and/or customized widgets like headlines
and dividers.
This example shows how to create a Scaffold that contains an AppBar and a Drawer. A user taps the "menu" icon in the AppBar to open the Drawer. The Drawer displays four items: A header and three menu items. The Drawer displays the four items using a ListView, which allows the user to scroll through the items if need be.
To see it in action, copy and run this code snippet on DartPad.
import 'package:material_ui/material_ui.dart';
/// Flutter code sample for [Drawer].
void main() => runApp(const DrawerApp());
class DrawerApp extends StatelessWidget {
const DrawerApp({super.key});
@override
Widget build(BuildContext context) {
return const MaterialApp(home: DrawerExample());
}
}
class DrawerExample extends StatefulWidget {
const DrawerExample({super.key});
@override
State<DrawerExample> createState() => _DrawerExampleState();
}
class _DrawerExampleState extends State<DrawerExample> {
String selectedPage = '';
@override
Widget build(BuildContext context) {
return Scaffold(
appBar: AppBar(title: const Text('Drawer Example')),
drawer: Drawer(
child: ListView(
padding: .zero,
children: <Widget>[
const DrawerHeader(
decoration: BoxDecoration(color: Colors.blue),
child: Text(
'Drawer Header',
style: TextStyle(color: Colors.white, fontSize: 24),
),
),
ListTile(
leading: const Icon(Icons.message),
title: const Text('Messages'),
onTap: () {
setState(() {
selectedPage = 'Messages';
});
},
),
ListTile(
leading: const Icon(Icons.account_circle),
title: const Text('Profile'),
onTap: () {
setState(() {
selectedPage = 'Profile';
});
},
),
ListTile(
leading: const Icon(Icons.settings),
title: const Text('Settings'),
onTap: () {
setState(() {
selectedPage = 'Settings';
});
},
),
],
),
),
body: Center(child: Text('Page: $selectedPage')),
);
}
}
This example shows how to migrate the above Drawer to a NavigationDrawer.
To see it in action, copy and run this code snippet on DartPad.
// Builds an adaptive navigation widget layout. When the screen width is less than
// 450, A [NavigationBar] will be displayed. Otherwise, a [NavigationRail] will be
// displayed on the left side, and also a button to open the [NavigationDrawer].
// All of these navigation widgets are built from an identical list of data.
import 'package:material_ui/material_ui.dart';
/// Flutter code sample for [NavigationDrawer].
void main() => runApp(const NavigationDrawerApp());
class ExampleDestination {
const ExampleDestination(this.label, this.icon, this.selectedIcon);
final String label;
final Widget icon;
final Widget selectedIcon;
}
const List<ExampleDestination> destinations = <ExampleDestination>[
ExampleDestination(
'Messages',
Icon(Icons.widgets_outlined),
Icon(Icons.widgets),
),
ExampleDestination(
'Profile',
Icon(Icons.format_paint_outlined),
Icon(Icons.format_paint),
),
ExampleDestination(
'Settings',
Icon(Icons.settings_outlined),
Icon(Icons.settings),
),
];
class NavigationDrawerApp extends StatelessWidget {
const NavigationDrawerApp({super.key});
@override
Widget build(BuildContext context) {
return const MaterialApp(
debugShowCheckedModeBanner: false,
home: NavigationDrawerExample(),
);
}
}
class NavigationDrawerExample extends StatefulWidget {
const NavigationDrawerExample({super.key});
@override
State<NavigationDrawerExample> createState() =>
_NavigationDrawerExampleState();
}
class _NavigationDrawerExampleState extends State<NavigationDrawerExample> {
final GlobalKey<ScaffoldState> scaffoldKey = GlobalKey<ScaffoldState>();
int screenIndex = 0;
late bool showNavigationDrawer;
void handleScreenChanged(int selectedScreen) {
setState(() {
screenIndex = selectedScreen;
});
}
void openDrawer() {
scaffoldKey.currentState!.openEndDrawer();
}
Widget buildBottomBarScaffold() {
return Scaffold(
body: Center(
child: Column(
mainAxisAlignment: .spaceEvenly,
children: <Widget>[Text('Page Index = $screenIndex')],
),
),
bottomNavigationBar: NavigationBar(
selectedIndex: screenIndex,
onDestinationSelected: (int index) {
setState(() {
screenIndex = index;
});
},
destinations: destinations.map((ExampleDestination destination) {
return NavigationDestination(
label: destination.label,
icon: destination.icon,
selectedIcon: destination.selectedIcon,
tooltip: destination.label,
);
}).toList(),
),
);
}
Widget buildDrawerScaffold(BuildContext context) {
return Scaffold(
key: scaffoldKey,
body: SafeArea(
bottom: false,
top: false,
child: Row(
children: <Widget>[
Padding(
padding: const .symmetric(horizontal: 5),
child: NavigationRail(
minWidth: 50,
destinations: destinations.map((
ExampleDestination destination,
) {
return NavigationRailDestination(
label: Text(destination.label),
icon: destination.icon,
selectedIcon: destination.selectedIcon,
);
}).toList(),
selectedIndex: screenIndex,
useIndicator: true,
onDestinationSelected: (int index) {
setState(() {
screenIndex = index;
});
},
),
),
const VerticalDivider(thickness: 1, width: 1),
Expanded(
child: Column(
mainAxisAlignment: .spaceEvenly,
children: <Widget>[
Text('Page Index = $screenIndex'),
ElevatedButton(
onPressed: openDrawer,
child: const Text('Open Drawer'),
),
],
),
),
],
),
),
endDrawer: NavigationDrawer(
onDestinationSelected: handleScreenChanged,
selectedIndex: screenIndex,
children: <Widget>[
Padding(
padding: const .fromLTRB(28, 16, 16, 10),
child: Text(
'Header',
style: Theme.of(context).textTheme.titleSmall,
),
),
...destinations.map((ExampleDestination destination) {
return NavigationDrawerDestination(
label: Text(destination.label),
icon: destination.icon,
selectedIcon: destination.selectedIcon,
);
}),
const Padding(padding: .fromLTRB(28, 16, 28, 10), child: Divider()),
],
),
);
}
@override
void didChangeDependencies() {
super.didChangeDependencies();
showNavigationDrawer = MediaQuery.widthOf(context) >= 450;
}
@override
Widget build(BuildContext context) {
return showNavigationDrawer
? buildDrawerScaffold(context)
: buildBottomBarScaffold();
}
}
An open drawer may be closed with a swipe to close gesture, pressing the escape key, by tapping the scrim, or by calling pop route function such as Navigator.pop. For example a drawer item might close the drawer when tapped:
ListTile(
leading: const Icon(Icons.change_history),
title: const Text('Change history'),
onTap: () {
// change app state...
Navigator.pop(context); // close the drawer
},
);
See also:
- Scaffold.drawer, where one specifies a Drawer so that it can be shown.
- Scaffold.of, to obtain the current ScaffoldState, which manages the display and animation of the drawer.
- ScaffoldState.openDrawer, which displays its Drawer, if any.
- material.io/design/components/navigation-drawer.html
- Inheritance
Constructors
Properties
- backgroundColor → Color?
-
Sets the color of the Material that holds all of the Drawer's
contents.
final
- child → Widget?
-
The widget below this widget in the tree.
final
- clipBehavior → Clip?
-
The content will be clipped (or not) according to this option.
final
- elevation → double?
-
The z-coordinate at which to place this drawer relative to its parent.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- semanticLabel → String?
-
The semantic label of the drawer used by accessibility frameworks to
announce screen transitions when the drawer is opened and closed.
final
- shadowColor → Color?
-
The color used to paint a drop shadow under the drawer's Material,
which reflects the drawer's elevation.
final
- shape → ShapeBorder?
-
The shape of the drawer.
final
- surfaceTintColor → Color?
-
The color used as a surface tint overlay on the drawer's background color,
which reflects the drawer's elevation.
final
- width → double?
-
The width of the drawer.
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited