style property
The text style to use for text in the dropdown button and the dropdown menu that appears when you tap the button.
To use a separate text style for selected item when it's displayed within the dropdown button, consider using selectedItemBuilder.
This sample shows a DropdownButton with a dropdown button text style
that is different than its menu items.
To see it in action, copy and run this code snippet on DartPad.
import 'package:material_ui/material_ui.dart';
/// Flutter code sample for [DropdownButton.style].
void main() => runApp(const DropdownButtonApp());
class DropdownButtonApp extends StatelessWidget {
const DropdownButtonApp({super.key});
@override
Widget build(BuildContext context) {
return MaterialApp(
home: Scaffold(
appBar: AppBar(title: const Text('DropdownButton Sample')),
body: const DropdownButtonExample(),
),
);
}
}
class DropdownButtonExample extends StatefulWidget {
const DropdownButtonExample({super.key});
@override
State<DropdownButtonExample> createState() => _DropdownButtonExampleState();
}
class _DropdownButtonExampleState extends State<DropdownButtonExample> {
List<String> options = <String>['One', 'Two', 'Three', 'Four'];
String dropdownValue = 'One';
@override
Widget build(BuildContext context) {
return Container(
alignment: .center,
color: Colors.blue,
child: DropdownButton<String>(
value: dropdownValue,
onChanged: (String? value) {
// This is called when the user selects an item.
setState(() {
dropdownValue = value!;
});
},
style: const TextStyle(color: Colors.blue),
selectedItemBuilder: (BuildContext context) {
// This is the widget that will be shown when you select an item.
// Here custom text style, alignment and layout size can be applied
// to selected item string.
return options.map((String value) {
return Align(
alignment: .centerLeft,
child: Text(
dropdownValue,
style: const TextStyle(color: Colors.white),
),
);
}).toList();
},
items: options.map<DropdownMenuItem<String>>((String value) {
return DropdownMenuItem<String>(value: value, child: Text(value));
}).toList(),
),
);
}
}
Defaults to the TextTheme.titleMedium value of the current ThemeData.textTheme of the current Theme.
Implementation
// TODO(framework): Replace the following block with a @dartpad directive
// when it's supported. https://github.com/dart-lang/dartdoc/issues/4123
/// {@macro material_ui.dartpad_guide}
///
/// {@example /example/lib/dropdown/dropdown_button.style.0.dart#body}
///
/// </callout-box>
///
/// Defaults to the [TextTheme.titleMedium] value of the current
/// [ThemeData.textTheme] of the current [Theme].
final TextStyle? style;