margin property
Applies a margin around each navigation item in the bar.
This creates space between adjacent destination items and between items and the bar edges. If null, defaults to EdgeInsets.zero.
Implementation
final EdgeInsetsGeometry? margin;