useIndicator property
- @override
- @Deprecated("Material 3 enforces the use of the selection indicator. To customize its " "appearance, use [indicatorColor] and [indicatorShape] instead of " "disabling it entirely. " "Material 2 is deprecated in Flutter and will be removed in v6.0.0 of this package. ")
final
Whether or not the selected NavigationRailDestination should include a NavigationIndicator.
Implementation
@override
// TODO(v6.0.0): Remove to deprecate M2.
@Deprecated(
"Material 3 enforces the use of the selection indicator. To customize its "
"appearance, use [indicatorColor] and [indicatorShape] instead of "
"disabling it entirely. "
"Material 2 is deprecated in Flutter and will be removed in v6.0.0 of this package. ",
)
final bool? useIndicator;